﻿using System.Windows;
using System;
using System.Collections.Generic;
using System.Globalization;
using Infragistics.Controls.Charts;


namespace ChartApp.Views
{
  /// <summary>
  /// Interaction logic for MainWindow.xaml
  /// </summary>
  public partial class MainWindow : Window
  {
    private readonly List<DataPoint> dataPoints = new List<DataPoint>();
    private string deviceName = "My Data";
    private bool inBackground = true;
    public MainWindow()
    {
      InitializeComponent();
    }


    private void ShowButtonClick(object sender, RoutedEventArgs e)
    {
      if (string.IsNullOrEmpty(MaxValue.Text) || string.IsNullOrEmpty(MinValue.Text))
      {
        return;
      }

      if (!int.TryParse(MaxValue.Text, out _) || !int.TryParse(MinValue.Text, out _))
      {
        return;
      }
      var max = int.Parse(MaxValue.Text);
      inBackground = true;
      var min = int.Parse(MinValue.Text);
      dataPoints.Clear();
      var endTime = DateTime.Now;
      var startTime = endTime.AddHours(-1);
      var valueGenerator = new Random();

      for (var i = 0; i < 60; i++)
      {
        dataPoints.Add(new DataPoint { DeviceName = deviceName, Value = valueGenerator.Next(min, max), TimeStamp = startTime.AddMinutes(i) });
      }
      CreateChart();
      CreatePolygon();
      ShowIntervalValue();
    }

    private void CreateChart()
    {
      ReportChart.Series.Clear();
      var serie = new ScatterLineSeries
      {
        Title = deviceName,
        ItemsSource = dataPoints,
        XMemberPath = "TimeStamp.Ticks",
        YMemberPath = "Value",
        XAxis = xAxis,
        YAxis = yAxis,
        MarkerType = MarkerType.Automatic
      };
      ReportChart.Series.Add(serie);
      ReportChart.UpdateLayout();
      ReportChart.Focus();
    }


    private void CreatePolygon()
    {

    }
    private void ShowIntervalValue()
    {
      ActualIntervalValue.Text = inBackground ? "XamDataChart in Background [" + yAxis.ActualInterval.ToString(CultureInfo.InvariantCulture) + "]" :
                                   "XamDataChart got focus [" + yAxis.ActualInterval.ToString(CultureInfo.InvariantCulture) + "]";
    }


    private void ChartTabOnGotFocus(object sender, RoutedEventArgs e)
    {
      inBackground = false;
      ShowIntervalValue();
    }
  }
}
